;;; 50mhc.el --- Debian mhc startup file  -*-mode: emacs-lisp;-*-
;;
;; Emacs startup file for the Debian GNU/Linux mhc package
;;
;; Originally contributed by Nils Naumann <naumann@unileoben.ac.at>
;; Modified by Dirk Eddelbuettel <edd@debian.org>
;; Adapted for dh-make by Jim Van Zandt <jrv@vanzandt.mv.com>

;; The mhc package follows the Debian/GNU Linux 'emacsen' policy and
;; byte-compiles its elisp files for each 'emacs flavor' (emacs19,
;; xemacs19, emacs20, xemacs20...).  The compiled code is then
;; installed in a subdirectory of the respective site-lisp directory.
;; We have to add this to the load-path:
(let ((elc-dir (concat "/usr/share/" (symbol-name flavor) "/site-lisp/mhc")))
  (if (not (file-directory-p elc-dir))
      ()
    (if (fboundp 'debian-pkg-add-load-path-item)
	(debian-pkg-add-load-path-item elc-dir)
      (setq load-path (cons elc-dir load-path)))
    (defun mhc-select-mailer-package (mua)
      "select mailer package for MHC: wl, mew or gnus"
      (interactive 
       (let ((mua-alist '(("wanderlust" . wl) ("mew" . mew) ("gnus" .gnus))))
	 (list (cdr (assoc
		     (completing-read "Mailer Package for MHC: " mua-alist)
		     mua-alist)))))
      (setq mhc-mailer-package mua)
      (cond 
       ((eq mhc-mailer-package 'wl)
	(autoload 'mhc-wl-setup "mhc-wl")
	(add-hook 'wl-init-hook 'mhc-wl-setup)
	(and (boundp 'wl-summary-mode-map)
	     (progn
	       (mhc-wl-setup)
	       (and (member major-mode '(wl-summary-mode wl-folder-mode))
		    (mhc-mode)))))
       ((eq mhc-mailer-package 'mew)
	(autoload 'mhc-mew-setup "mhc-mew")
	(add-hook 'mew-init-hook 'mhc-mew-setup)
	(and (boundp 'mew-summary-mode-map)
	     (progn
	       (mhc-mew-setup)
	       (and (member major-mode '(mew-summary-mode mew-virtual-mode))
		    (mhc-mode)))))
       ((eq mhc-mailer-package 'gnus)
	(autoload 'mhc-gnus-setup "mhc-gnus")
	(add-hook 'gnus-startup-hook 'mhc-gnus-setup)
	(and (boundp 'gnus-summary-mode-map)
	     (progn
	       (mhc-gnus-setup)
	       (and (member major-mode '(gnus-summary-mode gnus-group-mode))
		    (mhc-mode)))))))
    (setq mhc-icon-path
	  (if (or (featurep 'xemacs) (>= emacs-major-version 21))
	      "/usr/share/pixmaps/mhc"
	    "/usr/share/pixmaps/mhc/xbm"))))

; (setq mhc-base-folder "+schedule")
; (setq mhc-mail-path (expand-file-name "~/Mail"))

; see also /usr/share/doc/mhc/examples/DOT.schedule.sample

